@@ -25,15 +25,14 @@ from twisted.internet.defer import Deferred
 from ubuntuone.storageprotocol import protocol_pb2, sharersp, delta, request
 from ubuntuone.storageprotocol.client import (
     StorageClient, CreateUDF, ListVolumes, DeleteVolume, GetDelta,
-    Authenticate, MakeFile, MakeDir, PutContent, Move, Unlink
-)
+    Authenticate, MakeFile, MakeDir, PutContent, Move, Unlink)
 from ubuntuone.storageprotocol import volumes
 from tests import test_delta_info
 
 # let's not get picky about aatributes outside __init__ in tests
-# pylint: disable-msg=W0201
+# pylint: disable=W0201
 # it's ok to access internals in the test suite
-# pylint: disable-msg=W0212
+# pylint: disable=W0212
 
 PATH = u'~/Documents/pdfs/moño/'
 NAME = u'UDF-me'
@@ -43,6 +42,7 @@ NODE = uuid.UUID('FEDCBA98-7654-3211-2345-6789ABCDEF12')
 USER = u'Dude'
 GENERATION = 999
 
+
 class FakedError(Exception):
     """Stub to replace Request.error."""
 
@@ -51,41 +51,49 @@ def stub_function(*args, **kwargs):
     """Stub to replace non-related functions."""
     return None
 
+
 def faked_error(message):
     """Stub to replace Request.error."""
     raise FakedError
 
+
 def was_called(self, flag):
     """Helper to assert a function was called."""
     assert not getattr(self, flag)
+
     def set_flag(*args, **kwargs):
         """Record the calling was made."""
         setattr(self, flag, True)
     return set_flag
 
+
 def build_list_volumes():
     """Build a LIST_VOLUMES message."""
     message = protocol_pb2.Message()
     message.type = protocol_pb2.Message.VOLUMES_INFO
     return message
 
+
 def build_volume_created():
     """Build VOLUME_CREATED message."""
     message = protocol_pb2.Message()
     message.type = protocol_pb2.Message.VOLUME_CREATED
     return message
 
+
 def build_volume_deleted():
     """Build VOLUME_DELETED message."""
     message = protocol_pb2.Message()
     message.type = protocol_pb2.Message.VOLUME_DELETED
     return message
 
+
 def set_root_message(message):
     """Set a simple Root message."""
     message.type = protocol_pb2.Volumes.ROOT
     message.root.node = str(NODE)
 
+
 def set_udf_message(message):
     """Set a simple UDFs message."""
     message.type = protocol_pb2.Volumes.UDF
@@ -93,6 +101,7 @@ def set_udf_message(message):
     message.udf.node = str(NODE)
     message.udf.suggested_path = PATH
 
+
 def set_share_message(message):
     """Set a simple Share message."""
     message.type = protocol_pb2.Volumes.SHARE
@@ -105,6 +114,7 @@ def set_share_message(message):
     message.share.accepted = False
     message.share.access_level = 0
 
+
 class MethodMock(object):
     """A class to overwrite methods to know if they were called.
 
@@ -122,6 +132,7 @@ class MethodMock(object):
         self.called = True
         self.call_count += 1
 
+
 class DummyAttribute(object):
     """Helper class to replace non-related classes."""
 
@@ -400,7 +411,7 @@ class ClientTestCase(unittest.TestCase):
     def test_handle_volume_created_if_volume_is_buggy(self):
         """Test handle_VOLUME_CREATED if the volume is buggy."""
         message = build_volume_created()
-        message.volume_created.type = -1 # invalid type!
+        message.volume_created.type = -1  # invalid type!
         self.client.set_volume_created_callback(lambda vol: None)
         self.assertRaises(TypeError, self.client.handle_VOLUME_CREATED,
                           message)
@@ -617,6 +628,7 @@ class DeleteVolumeTestCase(unittest.TestCase):
 
         self.assertTrue(self.done_called, 'done() was called')
 
+
 class GetDeltaTestCase(unittest.TestCase):
     """Test cases for GetDelta op."""
 
@@ -703,6 +715,7 @@ class GetDeltaTestCase(unittest.TestCase):
         self.assertEquals(self.request.share_id,
                           actual_msg.get_delta.share)
 
+
 class TestAuth(unittest.TestCase):
     """Tests the authentication request."""
 
@@ -710,14 +723,14 @@ class TestAuth(unittest.TestCase):
         """Test that the request has the session id attribute."""
 
         SESSION_ID = "opaque_session_id"
-        request = Authenticate(FakedProtocol(), None)
-        request.done = MethodMock()
+        req = Authenticate(FakedProtocol(), None)
+        req.done = MethodMock()
         message = protocol_pb2.Message()
         message.type = protocol_pb2.Message.AUTH_AUTHENTICATED
         message.session_id = SESSION_ID
-        request.processMessage(message)
-        self.assert_(request.done.called)
-        self.assertEqual(request.session_id, SESSION_ID)
+        req.processMessage(message)
+        self.assert_(req.done.called)
+        self.assertEqual(req.session_id, SESSION_ID)
 
 
 class TestGenerationInRequests(unittest.TestCase):
@@ -737,12 +750,12 @@ class TestGenerationInRequests(unittest.TestCase):
 
     def test_make(self):
         """Test the request for new_generation."""
-        request = self.build_request()
-        request.done = MethodMock()
+        req = self.build_request()
+        req.done = MethodMock()
         message = self.build_message()
-        request.processMessage(message)
-        self.assert_(request.done.called)
-        self.assertEqual(request.new_generation, GENERATION)
+        req.processMessage(message)
+        self.assert_(req.done.called)
+        self.assertEqual(req.new_generation, GENERATION)
 
 
 class TestGenerationInRequestsMakeDir(TestGenerationInRequests):
