@@ -5,13 +5,13 @@
 #
 # Copyright (C) 2009 Canonical
 #
-# This program is free software: you can redistribute it and/or modify it 
+# This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU Affero General Public License version 3,
 # as published by the Free Software Foundation.
 #
-# This program is distributed in the hope that it will be useful, but 
-# WITHOUT ANY WARRANTY; without even the implied warranties of 
-# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
+# This program is distributed in the hope that it will be useful, but
+# WITHOUT ANY WARRANTY; without even the implied warranties of
+# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
 # PURPOSE.  See the GNU Affero General Public License for more details.
 #
 # You should have received a copy of the GNU Affero General Public License
@@ -20,11 +20,12 @@
 
 from __future__ import with_statement
 
-from unittest import TestCase
-from ubuntuone.storageprotocol.dircontent import \
-    parse_dir_content, write_dir_content, DirEntry, FILE, DIRECTORY, \
-    normalize_filename, validate_filename, InvalidFilename
 from cStringIO import StringIO
+from ubuntuone.storageprotocol.dircontent import (
+    parse_dir_content, write_dir_content, DirEntry,
+    normalize_filename, validate_filename, InvalidFilename)
+from ubuntuone.storageprotocol.dircontent_pb2 import (DIRECTORY, FILE)
+from unittest import TestCase
 
 
 class TestFilenames(TestCase):
@@ -103,8 +104,8 @@ class TestDirContent(TestCase):
         """
         a = DirEntry(name=u"negatory", node_type=FILE, uuid="abcd")
         b = DirEntry(name=u"beef", node_type=DIRECTORY, uuid="efgh")
-        buffer = StringIO()
-        write_dir_content([a, b], buffer)
-        buffer.seek(0, 0)
-        output_entries = [e for e in parse_dir_content(buffer)]
+        buf = StringIO()
+        write_dir_content([a, b], buf)
+        buf.seek(0, 0)
+        output_entries = [e for e in parse_dir_content(buf)]
         self.assertEqual(output_entries, [b, a])
