@@ -29,11 +29,10 @@ from twisted.python.failure import Failure
 
 from ubuntuone.storageprotocol import errors, protocol_pb2
 from ubuntuone.storageprotocol.request import (
-    RequestHandler, Request, RequestResponse
-)
+    RequestHandler, Request, RequestResponse)
 
 # let's not get picky about attributes outside __init__ in tests
-# pylint: disable-msg=W0201
+# pylint: disable=W0201
 
 
 class MindlessRequest(Request):
@@ -98,7 +97,7 @@ class TestRequest(TwistedTestCase):
         try:
             yield self.request.deferred
         except OurException:
-            pass # passed
+            pass  # passed
         else:
             self.fail("Expected to fail with the correct reason.")
 
@@ -155,8 +154,9 @@ class TestRequest(TwistedTestCase):
         """Test for sendError message."""
         error_type = protocol_pb2.Error.QUOTA_EXCEEDED
         comment = 'No more bytes for you.'
-        free_space_info = {'share_id':str(uuid.uuid4()), 'free_bytes':0}
+        free_space_info = {'share_id': str(uuid.uuid4()), 'free_bytes': 0}
         self.request.id = 1
+
         def check(message):
             """Check the message"""
             self.assertEqual(message.id, self.request.id)
