@@ -2,8 +2,10 @@
 #
 # Author: Lucio Torre <lucio.torre@canonical.com>
 # Author: Natalia B. Bidart <natalia.bidart@canonical.com>
+# Author: Guillermo Gonzalez <guillermo.gonzalez@canonical.com>
+# Author: Facundo Batista <facundo@canonical.com>
 #
-# Copyright 2009 Canonical Ltd.
+# Copyright 2009-2011 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU Affero General Public License version 3,
@@ -30,11 +32,11 @@ from twisted.internet import reactor, defer
 from twisted.python import log
 
 from ubuntuone.storageprotocol import (
-    protocol_pb2, request, sharersp, volumes, delta
-)
+    protocol_pb2, request, sharersp, volumes, delta)
 
 log_debug = partial(log.msg, loglevel=logging.DEBUG)
 
+
 class StorageClient(request.RequestHandler):
     """A Basic Storage Protocol client."""
 
@@ -83,7 +85,7 @@ class StorageClient(request.RequestHandler):
             except ValueError:
                 return
             self.line_mode = False
-            data = data[pos+2:]
+            data = data[pos + 2:]
 
         request.RequestHandler.dataReceived(self, data)
 
@@ -110,17 +112,17 @@ class StorageClient(request.RequestHandler):
         object when completed.
 
         """
-        request = oauth.OAuthRequest.from_consumer_and_token(
+        req = oauth.OAuthRequest.from_consumer_and_token(
             oauth_consumer=consumer,
             token=token,
             http_method="GET",
             http_url="storage://server")
-        request.sign_request(
+        req.sign_request(
             oauth.OAuthSignatureMethod_PLAINTEXT(), consumer, token)
 
         # Make sure all parameter values are strings.
         auth_parameters = dict(
-            (key, str(value)) for key, value in request.parameters.iteritems())
+            (key, str(value)) for key, value in req.parameters.iteritems())
         p = Authenticate(self, auth_parameters)
         p.start()
         return p.deferred
@@ -274,17 +276,25 @@ class StorageClient(request.RequestHandler):
         return p
 
     def put_content(self, share, node, previous_hash, new_hash,
-                    crc32, size, deflated_size, fd):
+                    crc32, size, deflated_size, fd, upload_id=None,
+                    upload_id_cb=None, magic_hash=None):
         """Put the content of fd into file node."""
         req = self.put_content_request(share, node, previous_hash, new_hash,
-                                       crc32, size, deflated_size, fd)
+                                       crc32, size, deflated_size, fd,
+                                       upload_id=upload_id,
+                                       upload_id_cb=upload_id_cb,
+                                       magic_hash=magic_hash)
         return req.deferred
 
     def put_content_request(self, share, node, previous_hash, new_hash,
-                            crc32, size, deflated_size, fd):
+                            crc32, size, deflated_size, fd, upload_id=None,
+                            upload_id_cb=None, magic_hash=None):
         """Put the content of fd into file node, return the request."""
         p = PutContent(self, share, node, previous_hash, new_hash,
-                       crc32, size, deflated_size, fd)
+                       crc32, size, deflated_size, fd,
+                       upload_id=upload_id,
+                       upload_id_cb=upload_id_cb,
+                       magic_hash=magic_hash)
         p.start()
         return p
 
@@ -382,7 +392,6 @@ class StorageClient(request.RequestHandler):
         else:
             raise TypeError('callback for share_change must be callable')
 
-
     def notify_share_change(self, notify_share):
         """Call the current changed share callback, if any, with the
         notify info.
@@ -418,7 +427,6 @@ class StorageClient(request.RequestHandler):
         else:
             raise TypeError('callback for share_answer must be callable')
 
-
     def notify_share_answer(self, msg):
         """Call the current share answer callback, if any, with the info.
 
@@ -595,7 +603,7 @@ class GetContent(request.Request):
 
     def processMessage(self, message):
         """Process messages."""
-        # pylint: disable-msg=W0201
+        # pylint: disable=W0201
         if message.type == protocol_pb2.Message.NODE_ATTR:
             if self.node_attr_callback is not None:
                 self.node_attr_callback(
@@ -644,7 +652,7 @@ class ListShares(request.Request):
 
     def _start(self):
         """Send the LIST_SHARES message to the server."""
-        # pylint: disable-msg=W0201
+        # pylint: disable=W0201
         message = protocol_pb2.Message()
         message.type = protocol_pb2.Message.LIST_SHARES
         self.sendMessage(message)
@@ -712,7 +720,7 @@ class CreateShare(request.Request):
             self.share_id = message.share_created.share_id
             self.done()
         elif message.type == protocol_pb2.Message.OK:
-            # XXX: this is for PROTOCOL_VERSION=1 backward compatibility
+            # this is for PROTOCOL_VERSION=1 backward compatibility
             self.done()
         else:
             self._default_process_message(message)
@@ -901,7 +909,7 @@ class Unlink(request.Request):
 
     @ivar new_generation: the generation that the volume is at now
     """
-    # pylint: disable-msg=C0111
+    # pylint: disable=C0111
 
     def __init__(self, protocol, share, node_id):
         """Request that node_id be unlinked
@@ -1032,7 +1040,7 @@ class Query(request.Request):
         """
         request.Request.__init__(self, protocol)
         self.query_message = qm = protocol_pb2.Message()
-        qm.id = 0 # just to have something in the field when calculating size
+        qm.id = 0  # just to have something in the field when calculating size
         qm.type = protocol_pb2.Message.QUERY
         self.response = []
         self.overflow = None
@@ -1075,9 +1083,12 @@ class Query(request.Request):
 class BytesMessageProducer(object):
     """Produce BYTES messages from a file."""
 
-    def __init__(self, request, fh, offset):
+    # to allow patching this in test and use task.Clock
+    callLater = reactor.callLater
+
+    def __init__(self, req, fh, offset):
         """Create a BytesMessageProducer."""
-        self.request = request
+        self.request = req
         self.producing = False
         self.fh = fh
         self.offset = offset
@@ -1116,7 +1127,7 @@ class BytesMessageProducer(object):
             response.type = protocol_pb2.Message.BYTES
             response.bytes.bytes = data
             self.request.sendMessage(response)
-            reactor.callLater(0, self.go)
+            self.callLater(0, self.go)
         else:
             message = protocol_pb2.Message()
             message.type = protocol_pb2.Message.EOF
@@ -1131,9 +1142,9 @@ class PutContent(request.Request):
     @ivar new_generation: the generation that the volume is at now
     """
 
-    def __init__(self, protocol, share, node_id,
-                 previous_hash, new_hash, crc32, size,
-                 deflated_size, fd):
+    def __init__(self, protocol, share, node_id, previous_hash, new_hash,
+                 crc32, size, deflated_size, fd, upload_id=None,
+                 upload_id_cb=None, magic_hash=None):
         """Put content into a node.
 
         @param protocol: the request handler
@@ -1144,6 +1155,10 @@ class PutContent(request.Request):
         @param crc32: the crc32 hint for the new content
         @param size: the size hint for the new content
         @param fd: a file-like object to read data from
+        @param upload_id: the upload id (to resume the upload.)
+        @param upload_id_cb: callback that will be called with the upload id
+                             assigned by the server for the session
+        @param magic_hash: the magic_hash of the file
 
         """
         request.Request.__init__(self, protocol)
@@ -1155,7 +1170,10 @@ class PutContent(request.Request):
         self.size = size
         self.deflated_size = deflated_size
         self.fd = fd
+        self.upload_id_cb = upload_id_cb
+        self.upload_id = upload_id
         self.new_generation = None
+        self.magic_hash = magic_hash
 
     def _start(self):
         """Send PUT_CONTENT."""
@@ -1168,11 +1186,19 @@ class PutContent(request.Request):
         message.put_content.crc32 = self.crc32
         message.put_content.size = self.size
         message.put_content.deflated_size = self.deflated_size
+        if self.upload_id:
+            message.put_content.upload_id = self.upload_id
+        if self.magic_hash is not None:
+            message.put_content.magic_hash = self.magic_hash
         self.sendMessage(message)
 
     def processMessage(self, message):
         """Handle messages."""
         if message.type == protocol_pb2.Message.BEGIN_CONTENT:
+            # call the upload_id_cb (if the upload_id it's in the message)
+            if message.begin_content.upload_id \
+               and self.upload_id_cb:
+                self.upload_id_cb(message.begin_content.upload_id)
             message_producer = BytesMessageProducer(
                 self, self.fd, message.begin_content.offset)
             self.registerProducer(message_producer, streaming=True)
@@ -1200,9 +1226,9 @@ class MakeObject(request.Request):
     node id of the created object.
 
     @cvar create_message: must be overridden with the correct creation message
-        to send
-    @cvar response_message: must be overridden with the correct creation success
-        message that will be received
+    to send
+    @cvar response_message: must be overridden with the correct creation
+    success message that will be received
 
     @ivar new_id: the id of the node that was created (available upon success)
     @ivar new_parent_id: the parent id the node now exists under
@@ -1237,7 +1263,7 @@ class MakeObject(request.Request):
 
     def processMessage(self, message):
         """Handle messages."""
-        # pylint: disable-msg=W0201
+        # pylint: disable=W0201
         if message.type == self.create_response:
             self.new_id = message.new.node
             self.new_parent_id = message.new.parent_node
@@ -1282,7 +1308,7 @@ class ProtocolVersion(request.Request):
 
     def processMessage(self, message):
         """Handle messages."""
-        # pylint: disable-msg=W0201
+        # pylint: disable=W0201
         if message.type == protocol_pb2.Message.PROTOCOL_VERSION:
             self.other_protocol_version = message.protocol.version
             self.done()
@@ -1382,7 +1408,7 @@ class FreeSpaceInquiry(request.Request):
 
     def _start(self):
         """Send the FREE_SPACE_INQUIRY message to the server."""
-        # pylint: disable-msg=W0201
+        # pylint: disable=W0201
         message = protocol_pb2.Message()
         message.type = protocol_pb2.Message.FREE_SPACE_INQUIRY
         message.free_space_inquiry.share_id = self.share_id
@@ -1391,6 +1417,7 @@ class FreeSpaceInquiry(request.Request):
 
     def processMessage(self, message):
         """Process the answer from the server."""
+        # pylint: disable=W0201
         if message.type == protocol_pb2.Message.FREE_SPACE_INFO:
             self.free_bytes = message.free_space_info.free_bytes
             self.done()
@@ -1403,7 +1430,7 @@ class AccountInquiry(request.Request):
 
     def _start(self):
         """Send the FREE_SPACE_INQUIRY message to the server."""
-        # pylint: disable-msg=W0201
+        # pylint: disable=W0201
         message = protocol_pb2.Message()
         message.type = protocol_pb2.Message.ACCOUNT_INQUIRY
         self.sendMessage(message)
@@ -1411,12 +1438,14 @@ class AccountInquiry(request.Request):
 
     def processMessage(self, message):
         """Process the answer from the server."""
+        # pylint: disable=W0201
         if message.type == protocol_pb2.Message.ACCOUNT_INFO:
             self.purchased_bytes = message.account_info.purchased_bytes
             self.done()
         else:
             self._default_process_message(message)
 
+
 class GetDelta(request.Request):
     """Get a delta on a volume
 
@@ -1480,6 +1509,7 @@ class GetDelta(request.Request):
         else:
             self._default_process_message(message)
 
+
 class ThrottlingStorageClient(StorageClient):
     """The throttling version of the StorageClient protocol."""
 
@@ -1534,7 +1564,7 @@ class ThrottlingStorageClient(StorageClient):
 
 class StorageClientFactory(ClientFactory):
     """StorageClient factory."""
-    # pylint: disable-msg=W0232
+    # pylint: disable=W0232
     protocol = StorageClient
 
 
@@ -1547,8 +1577,8 @@ class ThrottlingStorageClientFactory(StorageClientFactory, object):
     def __init__(self, throttling_enabled=False,
                  read_limit=None, write_limit=None):
         """Create the instance."""
-        self._readLimit = None # max bytes we should read per second
-        self._writeLimit = None # max bytes we should write per second
+        self._readLimit = None  # max bytes we should read per second
+        self._writeLimit = None  # max bytes we should write per second
         self._throttling_reads = False
         self._throttling_writes = False
         self._set_read_limit(read_limit)
@@ -1587,22 +1617,22 @@ class ThrottlingStorageClientFactory(StorageClientFactory, object):
         if not self.valid_limit(limit):
             raise ValueError('Read limit must be greater than 0.')
         self._readLimit = limit
-    # it's a property, pylint: disable-msg=W0212
+    # it's a property, pylint: disable=W0212
     readLimit = property(lambda self: self._readLimit, _set_read_limit)
     writeLimit = property(lambda self: self._writeLimit, _set_write_limit)
-    # pylint: enable-msg=W0212
+    # pylint: enable=W0212
 
     def callLater(self, period, func, *args, **kwargs):
         """Wrapper around L{reactor.callLater} for test purpose."""
         return reactor.callLater(period, func, *args, **kwargs)
 
-    def maybeCallLater(self, id, period, func):
+    def maybeCallLater(self, call_id, period, func):
         """Maybe run callLater(period, func).
 
         Only if we don't have a DelayedCall with the
         specified id already running.
         """
-        delayed_call = getattr(self, id)
+        delayed_call = getattr(self, call_id)
         # check if we already have a DelayedCall running
         if delayed_call is None or (not delayed_call.active() \
            and delayed_call.cancelled):
@@ -1621,9 +1651,9 @@ class ThrottlingStorageClientFactory(StorageClientFactory, object):
             self.readThisSecond += length
             self.checkReadBandwidth()
 
-    def _get_throttle_time(self, bytes, limit):
-        """Calculate the throttle_time for bytes and limit."""
-        return (float(bytes) / limit) - 1.0
+    def _get_throttle_time(self, data_bytes, limit):
+        """Calculate the throttle_time for data_bytes and limit."""
+        return (float(data_bytes) / limit) - 1.0
 
     def checkReadBandwidth(self):
         """Check if we've passed bandwidth limits."""
@@ -1662,11 +1692,11 @@ class ThrottlingStorageClientFactory(StorageClientFactory, object):
         self.resetReadThisSecondID = self.callLater(1,
                                                    self._resetReadThisSecond)
 
-    def _resetWrittenThisSecond (self):
+    def _resetWrittenThisSecond(self):
         """Reset the counter named with 'name' every 1 second."""
         self.writtenThisSecond = 0
-        self.resetWriteThisSecondID = self.callLater(1,
-                                                self._resetWrittenThisSecond)
+        self.resetWriteThisSecondID = self.callLater(
+            1, self._resetWrittenThisSecond)
 
     def throttleReads(self):
         """Throttle reads on all protocols."""
