@@ -21,6 +21,7 @@ import uuid
 
 from ubuntuone.storageprotocol import protocol_pb2
 
+# these are valid, pylint: disable=C0103
 _direction_prot2nice = {
     protocol_pb2.Shares.FROM_ME: "from_me",
     protocol_pb2.Shares.TO_ME:   "to_me",
@@ -32,6 +33,7 @@ _access_prot2nice = {
     protocol_pb2.Shares.MODIFY: "Modify",
 }
 _access_nice2prot = dict((y, x) for x, y in _access_prot2nice.items())
+# pylint: enable=C0103
 
 
 class Volume(object):
@@ -62,6 +64,7 @@ class Volume(object):
                   self.generation == other.generation)
         return result
 
+
 class ShareVolume(Volume):
     """A volume representing an accepted Share."""
 
@@ -86,13 +89,12 @@ class ShareVolume(Volume):
             node_id=uuid.UUID(msg.subtree),
             generation=msg.generation,
             free_bytes=msg.free_bytes,
-            direction = _direction_prot2nice[msg.direction],
+            direction=_direction_prot2nice[msg.direction],
             share_name=msg.share_name,
             other_username=msg.other_username,
             other_visible_name=msg.other_visible_name,
             accepted=msg.accepted,
-            access_level=_access_prot2nice[msg.access_level]
-        )
+            access_level=_access_prot2nice[msg.access_level])
         result = cls(**kwargs)
         return result
 
@@ -125,8 +127,7 @@ class UDFVolume(Volume):
             node_id=uuid.UUID(msg.node),
             generation=msg.generation,
             free_bytes=msg.free_bytes,
-            suggested_path=msg.suggested_path
-        )
+            suggested_path=msg.suggested_path)
         result = cls(**kwargs)
         return result
 
@@ -155,4 +156,3 @@ class RootVolume(Volume):
             free_bytes=msg.free_bytes)
         result = cls(**kwargs)
         return result
-
